import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useState } from "react";
import { ActionList, TextInput } from "@primer/react";
import { CheckIcon } from "@primer/octicons-react";
import NbGraderType, { getNbGraderType } from './NbGraderCells';
export const CellMetadataEditor = (props) => {
    var _a;
    const { cell } = props;
    const [cellGradeType, setCellGradeType] = useState(getNbGraderType(cell));
    const [nbg, setNbg] = useState((_a = cell.model.metadata) === null || _a === void 0 ? void 0 : _a.get('nbgrader'));
    const handleGradeIdChange = (cell, gradeId) => {
        const nbgrader = cell.model.metadata.get("nbgrader");
        cell.model.metadata.set("nbgrader", Object.assign(Object.assign({}, nbgrader), { grade_id: gradeId }));
        setNbg(Object.assign(Object.assign({}, nbg), { grade_id: gradeId }));
    };
    const handlePointsChange = (cell, points) => {
        var points_number = +points;
        if (!isNaN(points_number)) {
            const nbgrader = cell.model.metadata.get("nbgrader");
            cell.model.metadata.set("nbgrader", Object.assign(Object.assign({}, nbgrader), { points: points_number }));
            setNbg(Object.assign(Object.assign({}, nbg), { points: points_number }));
        }
    };
    const assignCellGradeType = (cell, cellGradeType) => {
        switch (cellGradeType) {
            case NbGraderType.NotGraded: {
                cell.model.metadata.delete("nbgrader");
                setCellGradeType(NbGraderType.NotGraded);
                break;
            }
            case NbGraderType.AutogradedAnswer: {
                const nbgrader = cell.model.metadata.get("nbgrader");
                cell.model.metadata.set("nbgrader", Object.assign(Object.assign({}, nbgrader), { "grade": false, "solution": true, "locked": false, "task": false }));
                setCellGradeType(NbGraderType.AutogradedAnswer);
                break;
            }
            case NbGraderType.AutogradedTest: {
                const nbgrader = cell.model.metadata.get("nbgrader");
                cell.model.metadata.set("nbgrader", Object.assign(Object.assign({}, nbgrader), { 
                    //        "points": 1,
                    "grade": true, "solution": false, "locked": false, "task": false }));
                setCellGradeType(NbGraderType.AutogradedTest);
                break;
            }
            case NbGraderType.ManuallyGradedAnswer: {
                const nbgrader = cell.model.metadata.get("nbgrader");
                cell.model.metadata.set("nbgrader", Object.assign(Object.assign({}, nbgrader), { 
                    //        "points": 1,
                    "grade": true, "solution": true, "locked": false, "task": false }));
                setCellGradeType(NbGraderType.ManuallyGradedAnswer);
                break;
            }
            case NbGraderType.ManuallyGradedTask: {
                const nbgrader = cell.model.metadata.get("nbgrader");
                cell.model.metadata.set("nbgrader", Object.assign(Object.assign({}, nbgrader), { 
                    //        "points": 1,
                    "grade": false, "solution": false, "locked": true, "task": true }));
                setCellGradeType(NbGraderType.ManuallyGradedTask);
                break;
            }
            case NbGraderType.ReadonlyGraded: {
                const nbgrader = cell.model.metadata.get("nbgrader");
                cell.model.metadata.set("nbgrader", Object.assign(Object.assign({}, nbgrader), { "grade": false, "solution": false, "locked": true, "task": false }));
                setCellGradeType(NbGraderType.ReadonlyGraded);
                break;
            }
        }
    };
    return (_jsxs(ActionList, Object.assign({ showDividers: true }, { children: [_jsx(ActionList.Divider, {}, void 0),
            _jsxs(ActionList.Group, Object.assign({ title: "NbGrader Cell Type", variant: "subtle" }, { children: [_jsxs(ActionList.Item, Object.assign({ onSelect: e => assignCellGradeType(cell, NbGraderType.NotGraded) }, { children: [cellGradeType === NbGraderType.NotGraded &&
                                _jsx(ActionList.LeadingVisual, { children: _jsx(CheckIcon, {}, void 0) }, void 0), "None", _jsx(ActionList.Description, Object.assign({ variant: "block" }, { children: "Not a grader cell." }), void 0)] }), void 0),
                    _jsxs(ActionList.Item, Object.assign({ onSelect: e => assignCellGradeType(cell, NbGraderType.AutogradedAnswer) }, { children: [cellGradeType === NbGraderType.AutogradedAnswer &&
                                _jsx(ActionList.LeadingVisual, { children: _jsx(CheckIcon, {}, void 0) }, void 0), "Autograded answer", _jsx(ActionList.Description, Object.assign({ variant: "block" }, { children: "An autograded answer cell." }), void 0)] }), void 0),
                    _jsxs(ActionList.Item, Object.assign({ role: "listitem", onClick: e => assignCellGradeType(cell, NbGraderType.AutogradedTest) }, { children: [cellGradeType === NbGraderType.AutogradedTest &&
                                _jsx(ActionList.LeadingVisual, { children: _jsx(CheckIcon, {}, void 0) }, void 0), "Autograded test", _jsx(ActionList.Description, Object.assign({ variant: "block" }, { children: "An autograded test cell." }), void 0)] }), void 0),
                    _jsxs(ActionList.Item, Object.assign({ onSelect: e => assignCellGradeType(cell, NbGraderType.ManuallyGradedTask) }, { children: [cellGradeType === NbGraderType.ManuallyGradedTask &&
                                _jsx(ActionList.LeadingVisual, { children: _jsx(CheckIcon, {}, void 0) }, void 0), "Manually graded task", _jsx(ActionList.Description, Object.assign({ variant: "block" }, { children: "A manually graded task cell." }), void 0)] }), void 0),
                    _jsxs(ActionList.Item, Object.assign({ onSelect: e => assignCellGradeType(cell, NbGraderType.ManuallyGradedAnswer) }, { children: [cellGradeType === NbGraderType.ManuallyGradedAnswer &&
                                _jsx(ActionList.LeadingVisual, { children: _jsx(CheckIcon, {}, void 0) }, void 0), "Manually graded answer", _jsx(ActionList.Description, Object.assign({ variant: "block" }, { children: "A manually graded answer cell." }), void 0)] }), void 0),
                    _jsxs(ActionList.Item, Object.assign({ onSelect: e => assignCellGradeType(cell, NbGraderType.ReadonlyGraded) }, { children: [cellGradeType === NbGraderType.ReadonlyGraded &&
                                _jsx(ActionList.LeadingVisual, { children: _jsx(CheckIcon, {}, void 0) }, void 0), "Readonly", _jsx(ActionList.Description, Object.assign({ variant: "block" }, { children: "A readonly grader cell." }), void 0)] }), void 0)] }), void 0),
            cellGradeType !== NbGraderType.NotGraded &&
                _jsxs(ActionList.Group, Object.assign({ title: "NbGrader Metadata", variant: "subtle" }, { children: [_jsxs(ActionList.Item, Object.assign({ onSelect: e => e.preventDefault() }, { children: ["Grade ID: ", nbg && _jsx(TextInput, { block: true, value: nbg.grade_id, onChange: e => { e.preventDefault(); handleGradeIdChange(cell, e.target.value); } }, void 0)] }), void 0),
                        _jsxs(ActionList.Item, { children: ["Points: ", nbg && _jsx(TextInput, { block: true, value: nbg.points, onChange: e => { e.preventDefault(); handlePointsChange(cell, e.target.value); } }, void 0)] }, void 0)] }), void 0)] }), void 0));
};
export default CellMetadataEditor;
//# sourceMappingURL=CellMetadataEditor.js.map