import { jsx as _jsx, jsxs as _jsxs } from "@emotion/react/jsx-runtime";
import { useState, useEffect } from 'react';
import { useDispatch, useSelector } from "react-redux";
import AddIcon from '@mui/icons-material/Add';
import { notebookActions, selectNotebook } from '../components/notebook/NotebookState';
import PlayArrowIcon from '@mui/icons-material/PlayArrow';
import FastForwardIcon from '@mui/icons-material/FastForward';
import StopIcon from '@mui/icons-material/Stop';
import SaveIcon from '@mui/icons-material/Save';
import DeleteIcon from '@mui/icons-material/Delete';
import IconButton from '@mui/material/IconButton';
import SyncIcon from '@mui/icons-material/Sync';
import Divider from '@mui/material/Divider';
import ToggleButton from '@mui/material/ToggleButton';
import ToggleButtonGroup from '@mui/material/ToggleButtonGroup';
import { styled } from '@mui/material/styles';
import { cmdIds } from '../components/notebook/NotebookCommands';
const StyledToggleButtonGroup = styled(ToggleButtonGroup)(({ theme }) => ({
    '& .MuiToggleButtonGroup-grouped': {
        margin: theme.spacing(0.5),
        border: 0,
        '&.Mui-disabled': {
            border: 0,
        },
        '&:not(:first-of-type)': {
            borderRadius: theme.shape.borderRadius,
        },
        '&:first-of-type': {
            borderRadius: theme.shape.borderRadius,
        },
    },
}));
const NotebookToolbarAdvanced = (props) => {
    const { notebookId } = props;
    const [autoSave, setAutoSave] = useState(true);
    const [addtype, setaddtype] = useState('code');
    const dispatch = useDispatch();
    const notebook = selectNotebook(notebookId);
    const notebook_state = useSelector((state) => {
        return state.notebook;
    });
    useEffect(() => {
        var _a;
        if (autoSave) {
            (_a = notebook === null || notebook === void 0 ? void 0 : notebook.adapter) === null || _a === void 0 ? void 0 : _a.commands.execute(cmdIds.save);
        }
    }, [notebook_state]);
    const handleChangeCellType = (event, newType) => {
        setaddtype(newType);
    };
    return (_jsxs("div", Object.assign({ style: { display: 'flex', width: '100%', borderBottom: '0.1rem solid lightgrey', position: 'relative', zIndex: '1', backgroundColor: 'white', top: '0' } }, { children: [_jsxs("div", Object.assign({ style: {
                    display: 'flex',
                    width: '50%',
                    paddingLeft: '7vw',
                    gap: '0.75vw',
                } }, { children: [_jsx(IconButton, Object.assign({ size: "small", color: "primary", "aria-label": "Save", onClick: (e) => { e.preventDefault(); dispatch(notebookActions.save.started({ uid: notebookId, date: new Date() })); }, style: { color: 'grey' } }, { children: _jsx(SaveIcon, { fontSize: "inherit" }, void 0) }), void 0),
                    _jsx(IconButton, Object.assign({ size: "small", color: "primary", "aria-label": "Insert Cell", onClick: (e) => {
                            e.preventDefault();
                            if (addtype === 'raw')
                                dispatch(notebookActions.insertBelow.started({ uid: notebookId, cellType: "raw" }));
                            else if (addtype === 'code')
                                dispatch(notebookActions.insertBelow.started({ uid: notebookId, cellType: "code" }));
                            else if (addtype === 'markdown')
                                dispatch(notebookActions.insertBelow.started({ uid: notebookId, cellType: "markdown" }));
                        }, style: { color: 'grey' } }, { children: _jsx(AddIcon, { fontSize: "inherit" }, void 0) }), void 0),
                    _jsx(IconButton, Object.assign({ size: "small", color: "secondary", "aria-label": "Run Cell", onClick: (e) => { e.preventDefault(); dispatch(notebookActions.run.started(notebookId)); }, style: { color: 'grey' } }, { children: _jsx(PlayArrowIcon, { fontSize: "inherit" }, void 0) }), void 0),
                    ((notebook === null || notebook === void 0 ? void 0 : notebook.kernelStatus) === 'idle') &&
                        _jsx(IconButton, Object.assign({ size: "small", color: "secondary", "aria-label": "Run All Cells", onClick: (e) => { e.preventDefault(); dispatch(notebookActions.runAll.started(notebookId)); }, style: { color: 'grey' } }, { children: _jsx(FastForwardIcon, { fontSize: "inherit" }, void 0) }), void 0),
                    ((notebook === null || notebook === void 0 ? void 0 : notebook.kernelStatus) === 'busy') &&
                        _jsx(IconButton, Object.assign({ size: "small", color: "error", "aria-label": "Interrupt", onClick: (e) => { e.preventDefault(); dispatch(notebookActions.interrupt.started(notebookId)); } }, { children: _jsx(StopIcon, { fontSize: "inherit", style: { color: '#e57373' } }, void 0) }), void 0),
                    _jsx(IconButton, Object.assign({ size: "small", color: "error", "aria-label": "Delete", onClick: (e) => { e.preventDefault(); dispatch(notebookActions.delete.started(notebookId)); } }, { children: _jsx(DeleteIcon, { fontSize: "inherit", style: { color: '#e57373' } }, void 0) }), void 0)] }), void 0),
            _jsxs("div", Object.assign({ style: {
                    display: 'flex',
                    width: '50%',
                    paddingRight: '7vw',
                    gap: '0.75vw',
                    justifyContent: 'flex-end',
                    alignItems: 'center'
                } }, { children: [_jsx(ToggleButton, Object.assign({ value: "Auto Save", selected: autoSave, onChange: (e) => {
                            e.preventDefault();
                            setAutoSave(!autoSave);
                        }, size: "small", color: autoSave ? "success" : "error", style: {
                            height: '1.5rem',
                            width: '1.5rem'
                        } }, { children: _jsx(SyncIcon, { fontSize: "small", style: { height: '1rem', width: '1rem' } }, void 0) }), void 0),
                    _jsx(Divider, { flexItem: true, orientation: "vertical", sx: { mx: 0.5, my: 1 } }, void 0),
                    _jsxs(StyledToggleButtonGroup, Object.assign({ size: "small", value: addtype, exclusive: true, onChange: handleChangeCellType, "aria-label": "text alignment" }, { children: [_jsx(ToggleButton, Object.assign({ value: "code", "aria-label": "left aligned" }, { children: _jsx("div", Object.assign({ style: { fontSize: '0.60rem' } }, { children: "Code" }), void 0) }), void 0),
                            _jsx(ToggleButton, Object.assign({ value: "markdown", "aria-label": "centered" }, { children: _jsx("div", Object.assign({ style: { fontSize: '0.60rem' } }, { children: "Markdown" }), void 0) }), void 0),
                            _jsx(ToggleButton, Object.assign({ value: "raw", "aria-label": "right aligned" }, { children: _jsx("div", Object.assign({ style: { fontSize: '0.60rem' } }, { children: "Raw" }), void 0) }), void 0)] }), void 0)] }), void 0)] }), void 0));
};
export default NotebookToolbarAdvanced;
//# sourceMappingURL=NotebookToolbar.js.map